@@ -37,7 +37,12 @@ SYSTEM_COLUMN_NAMES = (
     "sys_keywords",
 )
 
-_SYSTEM_COLUMN_SET = {name.lower() for name in SYSTEM_COLUMN_NAMES}
+# Legacy system columns retained for transitional compatibility checks.
+LEGACY_SYSTEM_COLUMN_NAMES = ("description",)
+
+_SYSTEM_COLUMN_SET = {
+    name.lower() for name in (*SYSTEM_COLUMN_NAMES, *LEGACY_SYSTEM_COLUMN_NAMES)
+}
 
 _NULLABLE_TRUE = {"YES", "TRUE", "T", "1", "Y"}
 _NULLABLE_FALSE = {"NO", "FALSE", "F", "0", "N"}
@@ -1307,7 +1312,11 @@ class Table:
         """
         Returns detailed information about all indexes on this table.
         """
-        sql, vals = self.sql.indexes(self.name)
+        sql_spec = self.sql.indexes(self.name)
+        if isinstance(sql_spec, tuple):
+            sql, vals = sql_spec
+        else:
+            sql, vals = sql_spec, tuple()
         if kwds.get("sql_only", False):
             return sql, vals
         return self.tx.execute(sql, vals, cursor=self.cursor())
