@@ -199,7 +199,9 @@ class TestTableComprehensive(CommonPostgresTest):
         
         # Test column filtering (non-sys columns)
         filtered_columns = table.columns()
-        sys_column_count = len([col for col in filtered_columns if col.startswith("sys_")])
+        sys_column_count = len(
+            [col for col in filtered_columns if table.is_system_column(col)]
+        )
         self.assertEqual(sys_column_count, 0)
 
     def test_table_row_count(self, tx):
